.. toolkit_cmm documentation master file, created by
   sphinx-quickstart on Tue May  9 22:52:33 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to toolkit_cmm
======================


User's Guide
------------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   user/index
   dev/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
